import * as i0 from '@angular/core';
import { InjectionToken, EventEmitter, booleanAttribute, Directive, Optional, Inject, Input, Output, inject, ChangeDetectorRef, ElementRef, ANIMATION_MODULE_TYPE, signal, Component, ViewEncapsulation, ChangeDetectionStrategy, NgModule, Injectable, SkipSelf, numberAttribute, HostBinding } from '@angular/core';
import { ReplaySubject, Subject, merge, BehaviorSubject, of, combineLatest } from 'rxjs';
import { FocusMonitor, AriaDescriber, _IdGenerator } from '@angular/cdk/a11y';
import { SPACE, ENTER } from '@angular/cdk/keycodes';
import * as i2 from '@angular/forms';
import { FormsModule } from '@angular/forms';
import { CdkCellDef, CdkHeaderCellDef, CdkFooterCellDef, CdkColumnDef, CdkHeaderCell, CdkFooterCell, CdkCell, DataSource, CdkHeaderRowDef, CdkFooterRowDef, CdkRowDef, CdkHeaderRow, CdkCellOutlet, CdkFooterRow, CdkRow, CdkNoDataRow, CdkTable, CDK_TABLE, _COALESCED_STYLE_SCHEDULER, _CoalescedStyleScheduler, STICKY_POSITIONING_LISTENER, HeaderRowOutlet, DataRowOutlet, NoDataRowOutlet, FooterRowOutlet, CdkTextColumn, CdkTableModule } from '@angular/cdk/table';
import { _isNumberValue } from '@angular/cdk/coercion';
import { map } from 'rxjs/operators';
import { _VIEW_REPEATER_STRATEGY, _RecycleViewRepeaterStrategy, _DisposeViewRepeaterStrategy } from '@angular/cdk/collections';

/** @docs-private */
function getSortDuplicateSortableIdError(id) {
    return Error(`Cannot have two NgbSortables with the same id (${id}).`);
}
/** @docs-private */
function getSortHeaderNotContainedWithinSortError() {
    return Error(`NgbSortHeader must be placed within a parent element with the NgbSort directive.`);
}
/** @docs-private */
function getSortHeaderMissingIdError() {
    return Error(`NgbSortHeader must be provided with a unique id.`);
}
/** @docs-private */
function getSortInvalidDirectionError(direction) {
    return Error(`${direction} is not a valid sort direction ('asc' or 'desc').`);
}

/**
 * @license
 * Original work Copyright Google LLC All Rights Reserved.
 * Modified work Copyright DatePoll-Systems
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */
/** Injection token to be used to override the default options for `ngb-sort`. */
const NGB_SORT_DEFAULT_OPTIONS = new InjectionToken('NGB_SORT_DEFAULT_OPTIONS');
/** Container for NgbSortable to manage the sort state and provide default sort parameters. */
class NgbSort {
    /** The sort direction of the currently active NgbSortable. */
    get direction() {
        return this._direction;
    }
    set direction(direction) {
        // @ts-expect-error ngDevMode not existing
        if (direction && direction !== 'asc' && direction !== 'desc' && (typeof ngDevMode === 'undefined' || ngDevMode)) {
            throw getSortInvalidDirectionError(direction);
        }
        this._direction = direction;
    }
    constructor(_defaultOptions) {
        this._defaultOptions = _defaultOptions;
        this._initializedStream = new ReplaySubject(1);
        /** Collection of all registered sortables that this directive manages. */
        this.sortables = new Map();
        /** Used to notify any child components listening to state changes. */
        this._stateChanges = new Subject();
        /** The id of the most recently sorted NgbSortable. */
        this.active = '';
        /**
         * The direction to set when an NgbSortable is initially sorted.
         * May be overriden by the NgbSortable's sort start.
         */
        this.start = 'asc';
        this._direction = '';
        /**
         * Whether to disable the user from clearing the sort by finishing the sort direction cycle.
         * May be overriden by the NgbSortable's disable clear input.
         */
        this.disableClear = false;
        /** Whether the sortable is disabled. */
        this.disabled = false;
        /** Event emitted when the user changes either the active sort or sort direction. */
        // eslint-disable-next-line @angular-eslint/no-output-rename
        this.sortChange = new EventEmitter();
        /** Emits when the paginator is initialized. */
        this.initialized = this._initializedStream;
    }
    /**
     * Register function to be used by the contained NgbSortables. Adds the NgbSortable to the
     * collection of NgbSortables.
     */
    register(sortable) {
        // @ts-expect-error ngDevMode not existing
        if (typeof ngDevMode === 'undefined' || ngDevMode) {
            if (!sortable.id) {
                throw getSortHeaderMissingIdError();
            }
            if (this.sortables.has(sortable.id)) {
                throw getSortDuplicateSortableIdError(sortable.id);
            }
        }
        this.sortables.set(sortable.id, sortable);
    }
    /**
     * Unregister function to be used by the contained NgbSortable. Removes the NgbSortable from the
     * collection of contained NgbSortable.
     */
    deregister(sortable) {
        this.sortables.delete(sortable.id);
    }
    /** Sets the active sort id and determines the new sort direction. */
    sort(sortable) {
        if (this.active != sortable.id) {
            this.active = sortable.id;
            this.direction = sortable.start ?? this.start;
        }
        else {
            this.direction = this.getNextSortDirection(sortable);
        }
        this.sortChange.emit({ active: this.active, direction: this.direction });
    }
    /** Returns the next sort direction of the active sortable, checking for potential overrides. */
    getNextSortDirection(sortable) {
        if (!sortable) {
            return '';
        }
        // Get the sort direction cycle with the potential sortable overrides.
        const disableClear = sortable?.disableClear ?? this.disableClear ?? !!this._defaultOptions?.disableClear;
        const sortDirectionCycle = getSortDirectionCycle(sortable.start || this.start, disableClear);
        // Get and return the next direction in the cycle
        let nextDirectionIndex = sortDirectionCycle.indexOf(this.direction) + 1;
        if (nextDirectionIndex >= sortDirectionCycle.length) {
            nextDirectionIndex = 0;
        }
        return sortDirectionCycle[nextDirectionIndex];
    }
    ngOnInit() {
        this._initializedStream.next();
    }
    ngOnChanges() {
        this._stateChanges.next();
    }
    ngOnDestroy() {
        this._stateChanges.complete();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.0.3", ngImport: i0, type: NgbSort, deps: [{ token: NGB_SORT_DEFAULT_OPTIONS, optional: true }], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "16.1.0", version: "19.0.3", type: NgbSort, isStandalone: true, selector: "[ngb-sort]", inputs: { active: ["ngbSortActive", "active"], start: ["ngbSortStart", "start"], direction: ["ngbSortDirection", "direction"], disableClear: ["ngbSortDisableClear", "disableClear", booleanAttribute], disabled: ["ngbSortDisabled", "disabled", booleanAttribute] }, outputs: { sortChange: "ngbSortChange" }, host: { classAttribute: "ngb-sort" }, exportAs: ["ngbSort"], usesOnChanges: true, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.0.3", ngImport: i0, type: NgbSort, decorators: [{
            type: Directive,
            args: [{
                    selector: '[ngb-sort]',
                    exportAs: 'ngbSort',
                    host: { class: 'ngb-sort' },
                }]
        }], ctorParameters: () => [{ type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [NGB_SORT_DEFAULT_OPTIONS]
                }] }], propDecorators: { active: [{
                type: Input,
                args: [{ alias: 'ngbSortActive' }]
            }], start: [{
                type: Input,
                args: ['ngbSortStart']
            }], direction: [{
                type: Input,
                args: ['ngbSortDirection']
            }], disableClear: [{
                type: Input,
                args: [{ alias: 'ngbSortDisableClear', transform: booleanAttribute }]
            }], disabled: [{
                type: Input,
                args: [{ alias: 'ngbSortDisabled', transform: booleanAttribute }]
            }], sortChange: [{
                type: Output,
                args: ['ngbSortChange']
            }] } });
/** Returns the sort direction cycle to use given the provided parameters of order and clear. */
function getSortDirectionCycle(start, disableClear) {
    const sortOrder = ['asc', 'desc'];
    if (start == 'desc') {
        sortOrder.reverse();
    }
    if (!disableClear) {
        sortOrder.push('');
    }
    return sortOrder;
}

/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * @license
 * Original work Copyright Google LLC All Rights Reserved.
 * Modified work Copyright DatePoll-Systems
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */
/**
 * Applies sorting behavior (click to change sort) and styles to an element, including an
 * arrow to display the current sort direction.
 *
 * Must be provided with an id and contained within a parent NgbSort directive.
 *
 * If used on header cells in a CdkTable, it will automatically default its id from its containing
 * column definition.
 */
class NgbSortHeader {
    /**
     * Description applied to NgbSortHeader's button element with aria-describedby. This text should
     * describe the action that will occur when the user clicks the sort header.
     */
    get sortActionDescription() {
        return this._sortActionDescription;
    }
    set sortActionDescription(value) {
        this._updateSortActionDescription(value);
    }
    constructor() {
        this._sort = inject(NgbSort, { optional: true });
        this._columnDef = inject('NGB_SORT_HEADER_COLUMN_DEF', {
            optional: true,
        });
        this._changeDetectorRef = inject(ChangeDetectorRef);
        this._focusMonitor = inject(FocusMonitor);
        this._elementRef = inject(ElementRef);
        this._ariaDescriber = inject(AriaDescriber, { optional: true });
        this._animationModule = inject(ANIMATION_MODULE_TYPE, { optional: true });
        /**
         * Indicates which state was just cleared from the sort header.
         * Will be reset on the next interaction. Used for coordinating animations.
         */
        this._recentlyCleared = signal(null);
        /** Sets the position of the arrow that displays when sorted. */
        this.arrowPosition = 'after';
        /** whether the sort header is disabled. */
        this.disabled = false;
        // Default the action description to "Sort" because it's better than nothing.
        // Without a description, the button's label comes from the sort header text content,
        // which doesn't give any indication that it performs a sorting operation.
        this._sortActionDescription = 'Sort';
        const defaultOptions = inject(NGB_SORT_DEFAULT_OPTIONS, {
            optional: true,
        });
        // @ts-expect-error ngDevMode not existing
        if (!this._sort && (typeof ngDevMode === 'undefined' || ngDevMode)) {
            throw getSortHeaderNotContainedWithinSortError();
        }
        if (defaultOptions?.arrowPosition) {
            this.arrowPosition = defaultOptions?.arrowPosition;
        }
    }
    ngOnInit() {
        if (!this.id && this._columnDef) {
            this.id = this._columnDef.name;
        }
        this._sort.register(this);
        this._renderChanges = merge(this._sort._stateChanges, this._sort.sortChange).subscribe(() => this._changeDetectorRef.markForCheck());
        this._sortButton = this._elementRef.nativeElement.querySelector('.ngb-sort-header-container');
        this._updateSortActionDescription(this._sortActionDescription);
    }
    ngAfterViewInit() {
        // We use the focus monitor because we also want to style
        // things differently based on the focus origin.
        this._focusMonitor.monitor(this._elementRef, true).subscribe(() => this._recentlyCleared.set(null));
    }
    ngOnDestroy() {
        this._focusMonitor.stopMonitoring(this._elementRef);
        this._sort.deregister(this);
        this._renderChanges?.unsubscribe();
        if (this._sortButton) {
            this._ariaDescriber?.removeDescription(this._sortButton, this._sortActionDescription);
        }
    }
    /** Triggers the sort on this sort header and removes the indicator hint. */
    _toggleOnInteraction() {
        if (!this._isDisabled()) {
            const wasSorted = this._isSorted();
            const prevDirection = this._sort.direction;
            this._sort.sort(this);
            this._recentlyCleared.set(wasSorted && !this._isSorted() ? prevDirection : null);
        }
    }
    _handleKeydown(event) {
        if (event.keyCode === SPACE || event.keyCode === ENTER) {
            event.preventDefault();
            this._toggleOnInteraction();
        }
    }
    /** Whether this NgbSortHeader is currently sorted in either ascending or descending order. */
    _isSorted() {
        return this._sort.active == this.id && (this._sort.direction === 'asc' || this._sort.direction === 'desc');
    }
    _isDisabled() {
        return this._sort.disabled || this.disabled;
    }
    /**
     * Gets the aria-sort attribute that should be applied to this sort header. If this header
     * is not sorted, returns null so that the attribute is removed from the host element. Aria spec
     * says that the aria-sort property should only be present on one header at a time, so removing
     * ensures this is true.
     */
    _getAriaSortAttribute() {
        if (!this._isSorted()) {
            return 'none';
        }
        return this._sort.direction == 'asc' ? 'ascending' : 'descending';
    }
    /** Whether the arrow inside the sort header should be rendered. */
    _renderArrow() {
        return !this._isDisabled() || this._isSorted();
    }
    _updateSortActionDescription(newDescription) {
        // We use AriaDescriber for the sort button instead of setting an `aria-label` because some
        // screen readers (notably VoiceOver) will read both the column header *and* the button's label
        // for every *cell* in the table, creating a lot of unnecessary noise.
        // If _sortButton is undefined, the component hasn't been initialized yet so there's
        // nothing to update in the DOM.
        if (this._sortButton) {
            // removeDescription will no-op if there is no existing message.
            // TODO(jelbourn): remove optional chaining when AriaDescriber is required.
            this._ariaDescriber?.removeDescription(this._sortButton, this._sortActionDescription);
            this._ariaDescriber?.describe(this._sortButton, newDescription);
        }
        this._sortActionDescription = newDescription;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.0.3", ngImport: i0, type: NgbSortHeader, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "19.0.3", type: NgbSortHeader, isStandalone: true, selector: "[ngb-sort-header]", inputs: { id: ["ngb-sort-header", "id"], arrowPosition: "arrowPosition", start: "start", disabled: ["disabled", "disabled", booleanAttribute], sortActionDescription: "sortActionDescription", disableClear: ["disableClear", "disableClear", booleanAttribute] }, host: { listeners: { "click": "_toggleOnInteraction()", "keydown": "_handleKeydown($event)", "mouseleave": "_recentlyCleared.set(null)" }, properties: { "attr.aria-sort": "_getAriaSortAttribute()", "class.ngb-sort-header-disabled": "_isDisabled()" }, classAttribute: "ngb-sort-header" }, exportAs: ["ngbSortHeader"], ngImport: i0, template: "<!--\n  We set the `tabindex` on an element inside the table header, rather than the header itself,\n  because of a bug in NVDA where having a `tabindex` on a `th` breaks keyboard navigation in the\n  table (see https://github.com/nvaccess/nvda/issues/7718). This allows for the header to both\n  be focusable, and have screen readers read out its `aria-sort` state. We prefer this approach\n  over having a button with an `aria-label` inside the header, because the button's `aria-label`\n  will be read out as the user is navigating the table's cell (see #13012).\n\n  The approach is based off of: https://dequeuniversity.com/library/aria/tables/sf-sortable-grid\n-->\n<div\n  class=\"ngb-sort-header-container ngb-focus-indicator\"\n  [class.ngb-sort-header-sorted]=\"_isSorted()\"\n  [class.ngb-sort-header-position-before]=\"arrowPosition === 'before'\"\n  [class.ngb-sort-header-descending]=\"this._sort.direction === 'desc'\"\n  [class.ngb-sort-header-ascending]=\"this._sort.direction === 'asc'\"\n  [class.ngb-sort-header-recently-cleared-ascending]=\"_recentlyCleared() === 'asc'\"\n  [class.ngb-sort-header-recently-cleared-descending]=\"_recentlyCleared() === 'desc'\"\n  [class.ngb-sort-header-animations-disabled]=\"_animationModule === 'NoopAnimations'\"\n  [attr.tabindex]=\"_isDisabled() ? null : 0\"\n  [attr.role]=\"_isDisabled() ? null : 'button'\"\n>\n  <!--\n    TODO(crisbeto): this div isn't strictly necessary, but we have to keep it due to a large\n    number of screenshot diff failures. It should be removed eventually. Note that the difference\n    isn't visible with a shorter header, but once it breaks up into multiple lines, this element\n    causes it to be center-aligned, whereas removing it will keep the text to the left.\n  -->\n  <div class=\"ngb-sort-header-content\">\n    <ng-content></ng-content>\n  </div>\n\n  <!-- Disable animations while a current animation is running -->\n  @if (_renderArrow()) {\n  <div class=\"ngb-sort-header-arrow\">\n    <svg viewBox=\"0 -960 960 960\" focusable=\"false\" aria-hidden=\"true\">\n      <path d=\"M440-240v-368L296-464l-56-56 240-240 240 240-56 56-144-144v368h-80Z\" />\n    </svg>\n  </div>\n  }\n</div>\n", styles: [".ngb-sort-header-container{display:flex;cursor:pointer;align-items:center;letter-spacing:normal;outline:0}[ngb-sort-header].cdk-keyboard-focused .ngb-sort-header-container,[ngb-sort-header].cdk-program-focused .ngb-sort-header-container{border-bottom:solid 1px currentColor}.ngb-sort-header-disabled .ngb-sort-header-container{cursor:default}.ngb-sort-header-content{text-align:center;display:flex;align-items:center}.ngb-sort-header-position-before{flex-direction:row-reverse}@keyframes ngb-sort-header-recently-cleared-ascending{0%{transform:translateY(0);opacity:1}to{transform:translateY(-25%);opacity:0}}@keyframes ngb-sort-header-recently-cleared-descending{0%{transform:translateY(0) rotate(180deg);opacity:1}to{transform:translateY(25%) rotate(180deg);opacity:0}}.ngb-sort-header-arrow{height:12px;width:12px;position:relative;transition:transform 225ms cubic-bezier(.4,0,.2,1),opacity 225ms cubic-bezier(.4,0,.2,1);opacity:0;overflow:visible}.ngb-sort-header:hover .ngb-sort-header-arrow{opacity:.54}.ngb-sort-header .ngb-sort-header-sorted .ngb-sort-header-arrow{opacity:1}.ngb-sort-header-descending .ngb-sort-header-arrow{transform:rotate(180deg)}.ngb-sort-header-recently-cleared-ascending .ngb-sort-header-arrow{transform:translateY(-25%)}.ngb-sort-header-recently-cleared-ascending .ngb-sort-header-arrow{transition:none;animation:_ngb-sort-header-recently-cleared-ascending 225ms cubic-bezier(.4,0,.2,1) forwards}.ngb-sort-header-recently-cleared-descending .ngb-sort-header-arrow{transition:none;animation:_ngb-sort-header-recently-cleared-descending 225ms cubic-bezier(.4,0,.2,1) forwards}.ngb-sort-header-animations-disabled .ngb-sort-header-arrow{transition-duration:0ms;animation-duration:0ms}.ngb-sort-header-arrow svg{width:24px;height:24px;fill:currentColor;position:absolute;top:50%;left:50%;margin:-12px 0 0 -12px;transform:translateZ(0)}.ngb-sort-header-arrow,[dir=rtl] .ngb-sort-header-position-before .ngb-sort-header-arrow{margin:0 0 0 6px}.ngb-sort-header-position-before .ngb-sort-header-arrow,[dir=rtl] .ngb-sort-header-arrow{margin:0 6px 0 0}\n"], changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.0.3", ngImport: i0, type: NgbSortHeader, decorators: [{
            type: Component,
            args: [{ selector: '[ngb-sort-header]', exportAs: 'ngbSortHeader', host: {
                        class: 'ngb-sort-header',
                        '(click)': '_toggleOnInteraction()',
                        '(keydown)': '_handleKeydown($event)',
                        '(mouseleave)': '_recentlyCleared.set(null)',
                        '[attr.aria-sort]': '_getAriaSortAttribute()',
                        '[class.ngb-sort-header-disabled]': '_isDisabled()',
                    }, encapsulation: ViewEncapsulation.None, changeDetection: ChangeDetectionStrategy.OnPush, template: "<!--\n  We set the `tabindex` on an element inside the table header, rather than the header itself,\n  because of a bug in NVDA where having a `tabindex` on a `th` breaks keyboard navigation in the\n  table (see https://github.com/nvaccess/nvda/issues/7718). This allows for the header to both\n  be focusable, and have screen readers read out its `aria-sort` state. We prefer this approach\n  over having a button with an `aria-label` inside the header, because the button's `aria-label`\n  will be read out as the user is navigating the table's cell (see #13012).\n\n  The approach is based off of: https://dequeuniversity.com/library/aria/tables/sf-sortable-grid\n-->\n<div\n  class=\"ngb-sort-header-container ngb-focus-indicator\"\n  [class.ngb-sort-header-sorted]=\"_isSorted()\"\n  [class.ngb-sort-header-position-before]=\"arrowPosition === 'before'\"\n  [class.ngb-sort-header-descending]=\"this._sort.direction === 'desc'\"\n  [class.ngb-sort-header-ascending]=\"this._sort.direction === 'asc'\"\n  [class.ngb-sort-header-recently-cleared-ascending]=\"_recentlyCleared() === 'asc'\"\n  [class.ngb-sort-header-recently-cleared-descending]=\"_recentlyCleared() === 'desc'\"\n  [class.ngb-sort-header-animations-disabled]=\"_animationModule === 'NoopAnimations'\"\n  [attr.tabindex]=\"_isDisabled() ? null : 0\"\n  [attr.role]=\"_isDisabled() ? null : 'button'\"\n>\n  <!--\n    TODO(crisbeto): this div isn't strictly necessary, but we have to keep it due to a large\n    number of screenshot diff failures. It should be removed eventually. Note that the difference\n    isn't visible with a shorter header, but once it breaks up into multiple lines, this element\n    causes it to be center-aligned, whereas removing it will keep the text to the left.\n  -->\n  <div class=\"ngb-sort-header-content\">\n    <ng-content></ng-content>\n  </div>\n\n  <!-- Disable animations while a current animation is running -->\n  @if (_renderArrow()) {\n  <div class=\"ngb-sort-header-arrow\">\n    <svg viewBox=\"0 -960 960 960\" focusable=\"false\" aria-hidden=\"true\">\n      <path d=\"M440-240v-368L296-464l-56-56 240-240 240 240-56 56-144-144v368h-80Z\" />\n    </svg>\n  </div>\n  }\n</div>\n", styles: [".ngb-sort-header-container{display:flex;cursor:pointer;align-items:center;letter-spacing:normal;outline:0}[ngb-sort-header].cdk-keyboard-focused .ngb-sort-header-container,[ngb-sort-header].cdk-program-focused .ngb-sort-header-container{border-bottom:solid 1px currentColor}.ngb-sort-header-disabled .ngb-sort-header-container{cursor:default}.ngb-sort-header-content{text-align:center;display:flex;align-items:center}.ngb-sort-header-position-before{flex-direction:row-reverse}@keyframes ngb-sort-header-recently-cleared-ascending{0%{transform:translateY(0);opacity:1}to{transform:translateY(-25%);opacity:0}}@keyframes ngb-sort-header-recently-cleared-descending{0%{transform:translateY(0) rotate(180deg);opacity:1}to{transform:translateY(25%) rotate(180deg);opacity:0}}.ngb-sort-header-arrow{height:12px;width:12px;position:relative;transition:transform 225ms cubic-bezier(.4,0,.2,1),opacity 225ms cubic-bezier(.4,0,.2,1);opacity:0;overflow:visible}.ngb-sort-header:hover .ngb-sort-header-arrow{opacity:.54}.ngb-sort-header .ngb-sort-header-sorted .ngb-sort-header-arrow{opacity:1}.ngb-sort-header-descending .ngb-sort-header-arrow{transform:rotate(180deg)}.ngb-sort-header-recently-cleared-ascending .ngb-sort-header-arrow{transform:translateY(-25%)}.ngb-sort-header-recently-cleared-ascending .ngb-sort-header-arrow{transition:none;animation:_ngb-sort-header-recently-cleared-ascending 225ms cubic-bezier(.4,0,.2,1) forwards}.ngb-sort-header-recently-cleared-descending .ngb-sort-header-arrow{transition:none;animation:_ngb-sort-header-recently-cleared-descending 225ms cubic-bezier(.4,0,.2,1) forwards}.ngb-sort-header-animations-disabled .ngb-sort-header-arrow{transition-duration:0ms;animation-duration:0ms}.ngb-sort-header-arrow svg{width:24px;height:24px;fill:currentColor;position:absolute;top:50%;left:50%;margin:-12px 0 0 -12px;transform:translateZ(0)}.ngb-sort-header-arrow,[dir=rtl] .ngb-sort-header-position-before .ngb-sort-header-arrow{margin:0 0 0 6px}.ngb-sort-header-position-before .ngb-sort-header-arrow,[dir=rtl] .ngb-sort-header-arrow{margin:0 6px 0 0}\n"] }]
        }], ctorParameters: () => [], propDecorators: { id: [{
                type: Input,
                args: ['ngb-sort-header']
            }], arrowPosition: [{
                type: Input
            }], start: [{
                type: Input
            }], disabled: [{
                type: Input,
                args: [{ transform: booleanAttribute }]
            }], sortActionDescription: [{
                type: Input
            }], disableClear: [{
                type: Input,
                args: [{ transform: booleanAttribute }]
            }] } });

/**
 * @license
 * Original work Copyright Google LLC All Rights Reserved.
 * Modified work Copyright DatePoll-Systems
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */
const EXPORTED_DECLARATIONS$1 = [NgbSort, NgbSortHeader];
class DfxSortModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.0.3", ngImport: i0, type: DfxSortModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "19.0.3", ngImport: i0, type: DfxSortModule, imports: [NgbSort, NgbSortHeader], exports: [NgbSort, NgbSortHeader] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "19.0.3", ngImport: i0, type: DfxSortModule }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.0.3", ngImport: i0, type: DfxSortModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: EXPORTED_DECLARATIONS$1,
                    exports: EXPORTED_DECLARATIONS$1,
                }]
        }] });

/**
 * To modify the labels and text displayed, create a new instance of NgbPaginatorIntl and
 * include it in a custom provider
 */
class NgbPaginatorIntl {
    constructor() {
        /**
         * Stream to emit from when labels are changed. Use this to notify components when the labels have
         * changed after initialization.
         */
        this.changes = new Subject();
        /** A label for the page size selector. */
        this.itemsPerPageLabel = 'Items per page:';
        /** A label for the button that increments the current page. */
        this.nextPageLabel = 'Next page';
        /** A label for the button that decrements the current page. */
        this.previousPageLabel = 'Previous page';
        /** A label for the button that moves to the first page. */
        this.firstPageLabel = 'First page';
        /** A label for the button that moves to the last page. */
        this.lastPageLabel = 'Last page';
        /** A label for the range of items within the current page and the length of the whole list. */
        this.getRangeLabel = (page, pageSize, length) => {
            if (length == 0 || pageSize == 0) {
                return `0 of ${length}`;
            }
            length = Math.max(length, 0);
            const startIndex = page * pageSize;
            // If the start index exceeds the list length, do not try and fix the end index to the end.
            const endIndex = startIndex < length ? Math.min(startIndex + pageSize, length) : startIndex + pageSize;
            return `${startIndex + 1} – ${endIndex} of ${length}`;
        };
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.0.3", ngImport: i0, type: NgbPaginatorIntl, deps: [], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "19.0.3", ngImport: i0, type: NgbPaginatorIntl, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.0.3", ngImport: i0, type: NgbPaginatorIntl, decorators: [{
            type: Injectable,
            args: [{ providedIn: 'root' }]
        }] });
/** @docs-private */
function NGB_PAGINATOR_INTL_PROVIDER_FACTORY(parentIntl) {
    return parentIntl || new NgbPaginatorIntl();
}
/** @docs-private */
const NGB_PAGINATOR_INTL_PROVIDER = {
    // If there is already an NgbPaginatorIntl available, use that. Otherwise, provide a new one.
    provide: NgbPaginatorIntl,
    deps: [[new Optional(), new SkipSelf(), NgbPaginatorIntl]],
    useFactory: NGB_PAGINATOR_INTL_PROVIDER_FACTORY,
};

/** The default page size if there is no page size and there are no provided page size options. */
const DEFAULT_PAGE_SIZE = 50;
/** Injection token that can be used to provide the default options for the paginator module. */
const NGB_PAGINATOR_DEFAULT_OPTIONS = new InjectionToken('NGB_PAGINATOR_DEFAULT_OPTIONS');
class NgbPaginator {
    /** The zero-based page index of the displayed list of items. Defaulted to 0. */
    get pageIndex() {
        return this._pageIndex;
    }
    set pageIndex(value) {
        this._pageIndex = Math.max(value || 0, 0);
        this._changeDetectorRef.markForCheck();
    }
    /** The length of the total number of items that are being paginated. Defaulted to 0. */
    get length() {
        return this._length;
    }
    set length(value) {
        this._length = value || 0;
        this._changeDetectorRef.markForCheck();
    }
    /** Number of items to display on a page. By default set to 50. */
    get pageSize() {
        return this._pageSize;
    }
    set pageSize(value) {
        this._pageSize = Math.max(value || 0, 0);
        this._updateDisplayedPageSizeOptions();
    }
    /** The set of provided page size options to display to the user. */
    get pageSizeOptions() {
        return this._pageSizeOptions;
    }
    set pageSizeOptions(value) {
        this._pageSizeOptions = (value || []).map((p) => numberAttribute(p, 0));
        this._updateDisplayedPageSizeOptions();
    }
    constructor(_intl, _changeDetectorRef, defaults) {
        this._intl = _intl;
        this._changeDetectorRef = _changeDetectorRef;
        /** ID for the DOM node containing the paginator's items per page label. */
        this._pageSizeLabelId = inject(_IdGenerator).getId('ngb-paginator-page-size-label-');
        this._isInitialized = false;
        this._initializedStream = new ReplaySubject(1);
        this._pageIndex = 0;
        this._length = 0;
        this._pageSizeOptions = [];
        /** Whether to hide the page size selection UI from the user. */
        this.hidePageSize = false;
        /** Whether to show the first/last buttons UI to the user. */
        this.showFirstLastButtons = false;
        /** Whether the paginator is disabled. */
        this.disabled = false;
        /** Event emitted when the paginator changes the page size or page index. */
        this.page = new EventEmitter();
        /** Emits when the paginator is initialized. */
        this.initialized = this._initializedStream;
        this._intlChanges = _intl.changes.subscribe(() => this._changeDetectorRef.markForCheck());
        if (defaults) {
            const { pageSize, pageSizeOptions, hidePageSize, showFirstLastButtons } = defaults;
            if (pageSize != null) {
                this.pageSize = pageSize;
            }
            if (pageSizeOptions != null) {
                this.pageSizeOptions = pageSizeOptions;
            }
            if (hidePageSize != null) {
                this.hidePageSize = hidePageSize;
            }
            if (showFirstLastButtons != null) {
                this.showFirstLastButtons = showFirstLastButtons;
            }
        }
    }
    ngOnInit() {
        this._isInitialized = true;
        this._updateDisplayedPageSizeOptions();
        this._initializedStream.next();
    }
    ngOnDestroy() {
        this._initializedStream.complete();
        this._intlChanges.unsubscribe();
    }
    /** Advances to the next page if it exists. */
    nextPage() {
        if (!this.hasNextPage()) {
            return;
        }
        const previousPageIndex = this.pageIndex;
        this.pageIndex = this.pageIndex + 1;
        this._emitPageEvent(previousPageIndex);
    }
    /** Move back to the previous page if it exists. */
    previousPage() {
        if (!this.hasPreviousPage()) {
            return;
        }
        const previousPageIndex = this.pageIndex;
        this.pageIndex = this.pageIndex - 1;
        this._emitPageEvent(previousPageIndex);
    }
    /** Move to the first page if not already there. */
    firstPage() {
        // hasPreviousPage being false implies at the start
        if (!this.hasPreviousPage()) {
            return;
        }
        const previousPageIndex = this.pageIndex;
        this.pageIndex = 0;
        this._emitPageEvent(previousPageIndex);
    }
    /** Move to the last page if not already there. */
    lastPage() {
        // hasNextPage being false implies at the end
        if (!this.hasNextPage()) {
            return;
        }
        const previousPageIndex = this.pageIndex;
        this.pageIndex = this.getNumberOfPages() - 1;
        this._emitPageEvent(previousPageIndex);
    }
    /** Whether there is a previous page. */
    hasPreviousPage() {
        return this.pageIndex >= 1 && this.pageSize !== 0;
    }
    /** Whether there is a next page. */
    hasNextPage() {
        const maxPageIndex = this.getNumberOfPages() - 1;
        return this.pageIndex < maxPageIndex && this.pageSize !== 0;
    }
    /** Calculate the number of pages */
    getNumberOfPages() {
        if (!this.pageSize) {
            return 0;
        }
        return Math.ceil(this.length / this.pageSize);
    }
    /**
     * Changes the page size so that the first item displayed on the page will still be
     * displayed using the new page size.
     *
     * For example, if the page size is 10 and on the second page (items indexed 10-19) then
     * switching so that the page size is 5 will set the third page as the current page so
     * that the 10th item will still be displayed.
     */
    _changePageSize(pageSize) {
        // Current page needs to be updated to reflect the new page size. Navigate to the page
        // containing the previous page's first item.
        const startIndex = this.pageIndex * this.pageSize;
        const previousPageIndex = this.pageIndex;
        this.pageIndex = Math.floor(startIndex / pageSize) || 0;
        this.pageSize = pageSize;
        this._emitPageEvent(previousPageIndex);
    }
    /** Checks whether the buttons for going forwards should be disabled. */
    _nextButtonsDisabled() {
        return this.disabled || !this.hasNextPage();
    }
    /** Checks whether the buttons for going backwards should be disabled. */
    _previousButtonsDisabled() {
        return this.disabled || !this.hasPreviousPage();
    }
    /**
     * Updates the list of page size options to display to the user. Includes making sure that
     * the page size is an option and that the list is sorted.
     */
    _updateDisplayedPageSizeOptions() {
        if (!this._isInitialized) {
            return;
        }
        // If no page size is provided, use the first page size option or the default page size.
        if (!this.pageSize) {
            this._pageSize = this.pageSizeOptions.length != 0 ? this.pageSizeOptions[0] : DEFAULT_PAGE_SIZE;
        }
        this._displayedPageSizeOptions = this.pageSizeOptions.slice();
        if (this._displayedPageSizeOptions.indexOf(this.pageSize) === -1) {
            this._displayedPageSizeOptions.push(this.pageSize);
        }
        // Sort the numbers using a number-specific sort function.
        this._displayedPageSizeOptions.sort((a, b) => a - b);
        this._changeDetectorRef.markForCheck();
    }
    /** Emits an event notifying that a change of the paginator's properties has been triggered. */
    _emitPageEvent(previousPageIndex) {
        this.page.emit({
            previousPageIndex,
            pageIndex: this.pageIndex,
            pageSize: this.pageSize,
            length: this.length,
        });
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.0.3", ngImport: i0, type: NgbPaginator, deps: [{ token: NgbPaginatorIntl }, { token: i0.ChangeDetectorRef }, { token: NGB_PAGINATOR_DEFAULT_OPTIONS, optional: true }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "19.0.3", type: NgbPaginator, isStandalone: true, selector: "ngb-paginator", inputs: { pageIndex: ["pageIndex", "pageIndex", numberAttribute], length: ["length", "length", numberAttribute], pageSize: ["pageSize", "pageSize", numberAttribute], pageSizeOptions: "pageSizeOptions", hidePageSize: ["hidePageSize", "hidePageSize", booleanAttribute], showFirstLastButtons: ["showFirstLastButtons", "showFirstLastButtons", booleanAttribute], disabled: ["disabled", "disabled", booleanAttribute], size: "size" }, outputs: { page: "page" }, host: { attributes: { "role": "group" } }, exportAs: ["ngbPaginator"], ngImport: i0, template: "<div\n  class=\"d-flex flex-column-reverse flex-lg-row justify-content-center justify-content-lg-end align-items-end align-items-lg-center gap-3 gap-lg-5\"\n>\n  @if (!hidePageSize) {\n  <div class=\"d-inline-flex gap-2 align-items-center\">\n    <small class=\"ws-nowrap\" [attr.id]=\"_pageSizeLabelId\"> {{ _intl.itemsPerPageLabel }} </small>\n\n    @if (_displayedPageSizeOptions.length > 1) {\n    <select\n      class=\"form-select form-select-sm\"\n      name=\"pageSize\"\n      [ngModel]=\"pageSize\"\n      [disabled]=\"disabled\"\n      [attr.aria-labelledby]=\"_pageSizeLabelId\"\n      (ngModelChange)=\"_changePageSize($any($event))\"\n    >\n      @for (pageSizeOption of _displayedPageSizeOptions; track pageSizeOption) {\n      <option [ngValue]=\"pageSizeOption\">{{ pageSizeOption }}</option>\n      }\n    </select>\n    } @if (_displayedPageSizeOptions.length <= 1) {\n    <small>{{pageSize}}</small>\n    }\n  </div>\n  }\n\n  <div class=\"d-inline-flex align-items-center gap-3 gap-lg-5\">\n    <small aria-live=\"polite\">{{ _intl.getRangeLabel(pageIndex, pageSize, length) }}</small>\n\n    <ul [class]=\"'my-0 pagination' + (size ? ' pagination-' + size : '')\">\n      @if (showFirstLastButtons) {\n      <li class=\"page-item\" [class.disabled]=\"_previousButtonsDisabled()\">\n        <button\n          type=\"button\"\n          class=\"page-link\"\n          (click)=\"firstPage()\"\n          [disabled]=\"_previousButtonsDisabled()\"\n          [attr.aria-label]=\"_intl.firstPageLabel\"\n          [attr.tabindex]=\"_previousButtonsDisabled() ? '-1' : null\"\n        >\n          <span aria-hidden=\"true\"> &laquo;&laquo;</span>\n        </button>\n      </li>\n      }\n\n      <li class=\"page-item\" [class.disabled]=\"_previousButtonsDisabled()\">\n        <button\n          type=\"button\"\n          class=\"page-link\"\n          (click)=\"previousPage()\"\n          [disabled]=\"_previousButtonsDisabled()\"\n          [attr.aria-label]=\"_intl.previousPageLabel\"\n          [attr.tabindex]=\"_previousButtonsDisabled() ? '-1' : null\"\n        >\n          <span aria-hidden=\"true\">&laquo;</span>\n        </button>\n      </li>\n      <li class=\"page-item\" [class.disabled]=\"_nextButtonsDisabled()\">\n        <button\n          type=\"button\"\n          class=\"page-link\"\n          (click)=\"nextPage()\"\n          [disabled]=\"_nextButtonsDisabled()\"\n          [attr.aria-label]=\"_intl.nextPageLabel\"\n          [attr.tabindex]=\"_nextButtonsDisabled() ? '-1' : null\"\n        >\n          <span aria-hidden=\"true\">&raquo;</span>\n        </button>\n      </li>\n\n      @if(showFirstLastButtons) {\n      <li class=\"page-item\" [class.disabled]=\"_nextButtonsDisabled()\">\n        <button\n          type=\"button\"\n          class=\"page-link\"\n          (click)=\"lastPage()\"\n          [disabled]=\"_nextButtonsDisabled()\"\n          [attr.aria-label]=\"_intl.lastPageLabel\"\n          [attr.tabindex]=\"_nextButtonsDisabled() ? '-1' : null\"\n        >\n          <span aria-hidden=\"true\">&raquo;&raquo;</span>\n        </button>\n      </li>\n      }\n    </ul>\n  </div>\n</div>\n", styles: [".ws-nowrap{white-space:nowrap}\n"], dependencies: [{ kind: "ngmodule", type: FormsModule }, { kind: "directive", type: i2.NgSelectOption, selector: "option", inputs: ["ngValue", "value"] }, { kind: "directive", type: i2.ɵNgSelectMultipleOption, selector: "option", inputs: ["ngValue", "value"] }, { kind: "directive", type: i2.SelectControlValueAccessor, selector: "select:not([multiple])[formControlName],select:not([multiple])[formControl],select:not([multiple])[ngModel]", inputs: ["compareWith"] }, { kind: "directive", type: i2.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i2.NgModel, selector: "[ngModel]:not([formControlName]):not([formControl])", inputs: ["name", "disabled", "ngModel", "ngModelOptions"], outputs: ["ngModelChange"], exportAs: ["ngModel"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.0.3", ngImport: i0, type: NgbPaginator, decorators: [{
            type: Component,
            args: [{ selector: 'ngb-paginator', exportAs: 'ngbPaginator', host: {
                        role: 'group',
                    }, changeDetection: ChangeDetectionStrategy.OnPush, encapsulation: ViewEncapsulation.None, imports: [FormsModule], template: "<div\n  class=\"d-flex flex-column-reverse flex-lg-row justify-content-center justify-content-lg-end align-items-end align-items-lg-center gap-3 gap-lg-5\"\n>\n  @if (!hidePageSize) {\n  <div class=\"d-inline-flex gap-2 align-items-center\">\n    <small class=\"ws-nowrap\" [attr.id]=\"_pageSizeLabelId\"> {{ _intl.itemsPerPageLabel }} </small>\n\n    @if (_displayedPageSizeOptions.length > 1) {\n    <select\n      class=\"form-select form-select-sm\"\n      name=\"pageSize\"\n      [ngModel]=\"pageSize\"\n      [disabled]=\"disabled\"\n      [attr.aria-labelledby]=\"_pageSizeLabelId\"\n      (ngModelChange)=\"_changePageSize($any($event))\"\n    >\n      @for (pageSizeOption of _displayedPageSizeOptions; track pageSizeOption) {\n      <option [ngValue]=\"pageSizeOption\">{{ pageSizeOption }}</option>\n      }\n    </select>\n    } @if (_displayedPageSizeOptions.length <= 1) {\n    <small>{{pageSize}}</small>\n    }\n  </div>\n  }\n\n  <div class=\"d-inline-flex align-items-center gap-3 gap-lg-5\">\n    <small aria-live=\"polite\">{{ _intl.getRangeLabel(pageIndex, pageSize, length) }}</small>\n\n    <ul [class]=\"'my-0 pagination' + (size ? ' pagination-' + size : '')\">\n      @if (showFirstLastButtons) {\n      <li class=\"page-item\" [class.disabled]=\"_previousButtonsDisabled()\">\n        <button\n          type=\"button\"\n          class=\"page-link\"\n          (click)=\"firstPage()\"\n          [disabled]=\"_previousButtonsDisabled()\"\n          [attr.aria-label]=\"_intl.firstPageLabel\"\n          [attr.tabindex]=\"_previousButtonsDisabled() ? '-1' : null\"\n        >\n          <span aria-hidden=\"true\"> &laquo;&laquo;</span>\n        </button>\n      </li>\n      }\n\n      <li class=\"page-item\" [class.disabled]=\"_previousButtonsDisabled()\">\n        <button\n          type=\"button\"\n          class=\"page-link\"\n          (click)=\"previousPage()\"\n          [disabled]=\"_previousButtonsDisabled()\"\n          [attr.aria-label]=\"_intl.previousPageLabel\"\n          [attr.tabindex]=\"_previousButtonsDisabled() ? '-1' : null\"\n        >\n          <span aria-hidden=\"true\">&laquo;</span>\n        </button>\n      </li>\n      <li class=\"page-item\" [class.disabled]=\"_nextButtonsDisabled()\">\n        <button\n          type=\"button\"\n          class=\"page-link\"\n          (click)=\"nextPage()\"\n          [disabled]=\"_nextButtonsDisabled()\"\n          [attr.aria-label]=\"_intl.nextPageLabel\"\n          [attr.tabindex]=\"_nextButtonsDisabled() ? '-1' : null\"\n        >\n          <span aria-hidden=\"true\">&raquo;</span>\n        </button>\n      </li>\n\n      @if(showFirstLastButtons) {\n      <li class=\"page-item\" [class.disabled]=\"_nextButtonsDisabled()\">\n        <button\n          type=\"button\"\n          class=\"page-link\"\n          (click)=\"lastPage()\"\n          [disabled]=\"_nextButtonsDisabled()\"\n          [attr.aria-label]=\"_intl.lastPageLabel\"\n          [attr.tabindex]=\"_nextButtonsDisabled() ? '-1' : null\"\n        >\n          <span aria-hidden=\"true\">&raquo;&raquo;</span>\n        </button>\n      </li>\n      }\n    </ul>\n  </div>\n</div>\n", styles: [".ws-nowrap{white-space:nowrap}\n"] }]
        }], ctorParameters: () => [{ type: NgbPaginatorIntl }, { type: i0.ChangeDetectorRef }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [NGB_PAGINATOR_DEFAULT_OPTIONS]
                }] }], propDecorators: { pageIndex: [{
                type: Input,
                args: [{ transform: numberAttribute }]
            }], length: [{
                type: Input,
                args: [{ transform: numberAttribute }]
            }], pageSize: [{
                type: Input,
                args: [{ transform: numberAttribute }]
            }], pageSizeOptions: [{
                type: Input
            }], hidePageSize: [{
                type: Input,
                args: [{ transform: booleanAttribute }]
            }], showFirstLastButtons: [{
                type: Input,
                args: [{ transform: booleanAttribute }]
            }], disabled: [{
                type: Input,
                args: [{ transform: booleanAttribute }]
            }], size: [{
                type: Input
            }], page: [{
                type: Output
            }] } });

class DfxPaginationModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.0.3", ngImport: i0, type: DfxPaginationModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "19.0.3", ngImport: i0, type: DfxPaginationModule, imports: [NgbPaginator], exports: [NgbPaginator] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "19.0.3", ngImport: i0, type: DfxPaginationModule, providers: [NGB_PAGINATOR_INTL_PROVIDER], imports: [NgbPaginator] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.0.3", ngImport: i0, type: DfxPaginationModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [NgbPaginator],
                    exports: [NgbPaginator],
                    providers: [NGB_PAGINATOR_INTL_PROVIDER],
                }]
        }] });

/**
 * @license
 * Original work Copyright Google LLC All Rights Reserved.
 * Modified work Copyright DatePoll-Systems
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */
/**
 * Cell definition for the ngb-table.
 * Captures the template of a column's data row cell as well as cell-specific properties.
 */
class NgbCellDef extends CdkCellDef {
    // ngTemplateContextGuard flag to help with the Language Service
    static ngTemplateContextGuard(dir, ctx) {
        return true;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.0.3", ngImport: i0, type: NgbCellDef, deps: null, target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "19.0.3", type: NgbCellDef, isStandalone: true, selector: "[ngbCellDef]", inputs: { ngbCellDefTable: "ngbCellDefTable" }, providers: [{ provide: CdkCellDef, useExisting: NgbCellDef }], usesInheritance: true, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.0.3", ngImport: i0, type: NgbCellDef, decorators: [{
            type: Directive,
            args: [{
                    selector: '[ngbCellDef]',
                    providers: [{ provide: CdkCellDef, useExisting: NgbCellDef }],
                    standalone: true,
                }]
        }], propDecorators: { ngbCellDefTable: [{
                type: Input
            }] } });
/**
 * Header cell definition for the ngb-table.
 * Captures the template of a column's header cell and as well as cell-specific properties.
 */
class NgbHeaderCellDef extends CdkHeaderCellDef {
    constructor() {
        super(...arguments);
        this.whiteSpace = 'nowrap';
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.0.3", ngImport: i0, type: NgbHeaderCellDef, deps: null, target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "19.0.3", type: NgbHeaderCellDef, isStandalone: true, selector: "[ngbHeaderCellDef]", inputs: { whiteSpace: "whiteSpace" }, host: { properties: { "style.white-space": "this.whiteSpace" } }, providers: [{ provide: CdkHeaderCellDef, useExisting: NgbHeaderCellDef }], usesInheritance: true, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.0.3", ngImport: i0, type: NgbHeaderCellDef, decorators: [{
            type: Directive,
            args: [{
                    selector: '[ngbHeaderCellDef]',
                    providers: [{ provide: CdkHeaderCellDef, useExisting: NgbHeaderCellDef }],
                    standalone: true,
                }]
        }], propDecorators: { whiteSpace: [{
                type: HostBinding,
                args: ['style.white-space']
            }, {
                type: Input
            }] } });
/**
 * Footer cell definition for the ngb-table.
 * Captures the template of a column's footer cell and as well as cell-specific properties.
 */
class NgbFooterCellDef extends CdkFooterCellDef {
    constructor() {
        super(...arguments);
        this.whiteSpace = 'nowrap';
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.0.3", ngImport: i0, type: NgbFooterCellDef, deps: null, target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "19.0.3", type: NgbFooterCellDef, isStandalone: true, selector: "[ngbFooterCellDef]", inputs: { whiteSpace: "whiteSpace" }, host: { properties: { "style.white-space": "this.whiteSpace" } }, providers: [{ provide: CdkFooterCellDef, useExisting: NgbFooterCellDef }], usesInheritance: true, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.0.3", ngImport: i0, type: NgbFooterCellDef, decorators: [{
            type: Directive,
            args: [{
                    selector: '[ngbFooterCellDef]',
                    providers: [{ provide: CdkFooterCellDef, useExisting: NgbFooterCellDef }],
                    standalone: true,
                }]
        }], propDecorators: { whiteSpace: [{
                type: HostBinding,
                args: ['style.white-space']
            }, {
                type: Input
            }] } });
/**
 * Column definition for the ngb-table.
 * Defines a set of cells available for a table column.
 */
class NgbColumnDef extends CdkColumnDef {
    /** Unique name for this column. */
    get name() {
        return this._name;
    }
    set name(name) {
        this._setNameInput(name);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.0.3", ngImport: i0, type: NgbColumnDef, deps: null, target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "19.0.3", type: NgbColumnDef, isStandalone: true, selector: "[ngbColumnDef]", inputs: { name: ["ngbColumnDef", "name"] }, providers: [
            { provide: CdkColumnDef, useExisting: NgbColumnDef },
            { provide: 'NGB_SORT_HEADER_COLUMN_DEF', useExisting: NgbColumnDef },
        ], usesInheritance: true, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.0.3", ngImport: i0, type: NgbColumnDef, decorators: [{
            type: Directive,
            args: [{
                    selector: '[ngbColumnDef]',
                    providers: [
                        { provide: CdkColumnDef, useExisting: NgbColumnDef },
                        { provide: 'NGB_SORT_HEADER_COLUMN_DEF', useExisting: NgbColumnDef },
                    ],
                    standalone: true,
                }]
        }], propDecorators: { name: [{
                type: Input,
                args: ['ngbColumnDef']
            }] } });
/** Header cell template container that adds the right classes and role. */
class NgbHeaderCell extends CdkHeaderCell {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.0.3", ngImport: i0, type: NgbHeaderCell, deps: null, target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "19.0.3", type: NgbHeaderCell, isStandalone: true, selector: "ngb-header-cell, th[ngb-header-cell]", host: { attributes: { "role": "columnheader" } }, usesInheritance: true, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.0.3", ngImport: i0, type: NgbHeaderCell, decorators: [{
            type: Directive,
            args: [{
                    selector: 'ngb-header-cell, th[ngb-header-cell]',
                    host: {
                        role: 'columnheader',
                    },
                    standalone: true,
                }]
        }] });
/** Footer cell template container that adds the right classes and role. */
class NgbFooterCell extends CdkFooterCell {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.0.3", ngImport: i0, type: NgbFooterCell, deps: null, target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "19.0.3", type: NgbFooterCell, isStandalone: true, selector: "ngb-footer-cell, td[ngb-footer-cell]", usesInheritance: true, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.0.3", ngImport: i0, type: NgbFooterCell, decorators: [{
            type: Directive,
            args: [{
                    selector: 'ngb-footer-cell, td[ngb-footer-cell]',
                    standalone: true,
                }]
        }] });
/** Cell template container that adds the right classes and role. */
class NgbCell extends CdkCell {
    constructor() {
        super(...arguments);
        this.whiteSpace = 'nowrap';
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.0.3", ngImport: i0, type: NgbCell, deps: null, target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "19.0.3", type: NgbCell, isStandalone: true, selector: "ngb-cell, td[ngb-cell]", inputs: { whiteSpace: "whiteSpace" }, host: { properties: { "style.white-space": "this.whiteSpace" } }, usesInheritance: true, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.0.3", ngImport: i0, type: NgbCell, decorators: [{
            type: Directive,
            args: [{
                    selector: 'ngb-cell, td[ngb-cell]',
                    standalone: true,
                }]
        }], propDecorators: { whiteSpace: [{
                type: HostBinding,
                args: ['style.white-space']
            }, {
                type: Input
            }] } });

/**
 * @license
 * Original work Copyright Google LLC All Rights Reserved.
 * Modified work Copyright DatePoll-Systems
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */
/**
 * Corresponds to `Number.MAX_SAFE_INTEGER`. Moved out into a variable here due to
 * flaky browser support and the value not being defined in Closure's typings.
 */
const MAX_SAFE_INTEGER = 9007199254740991;
/**
 * Data source that accepts a client-side data array and includes native support of filtering,
 * sorting (using NgbSort), and pagination (using NgbPaginator).
 *
 * Allows for sort customization by overriding sortingDataAccessor, which defines how data
 * properties are accessed. Also allows for filter customization by overriding filterPredicate,
 * which defines how row data is converted to a string for filter matching.
 *
 * **Note:** This class is meant to be a simple data source to help you get started. As such
 * it isn't equipped to handle some more advanced cases like robust i18n support or server-side
 * interactions. If your app needs to support more advanced use cases, consider implementing your
 * own `DataSource`.
 */
class NgbTableDataSource extends DataSource {
    /** Array of data that should be rendered by the table, where each object represents one row. */
    get data() {
        return this._data.value;
    }
    set data(data) {
        data = Array.isArray(data) ? data : [];
        this._data.next(data);
        // Normally the `filteredData` is updated by the re-render
        // subscription, but that won't happen if it's inactive.
        if (!this._renderChangesSubscription) {
            this._filterData(data);
        }
    }
    /**
     * Filter term that should be used to filter out objects from the data array. To override how
     * data objects match to this filter string, provide a custom function for filterPredicate.
     */
    get filter() {
        return this._filter.value;
    }
    set filter(filter) {
        this._filter.next(filter);
        // Normally the `filteredData` is updated by the re-render
        // subscription, but that won't happen if it's inactive.
        if (!this._renderChangesSubscription) {
            this._filterData(this.data);
        }
    }
    /**
     * Instance of the NgbSort directive used by the table to control its sorting. Sort changes
     * emitted by the NgbSort will trigger an update to the table's rendered data.
     */
    get sort() {
        return this._sort;
    }
    set sort(sort) {
        this._sort = sort;
        this._updateChangeSubscription();
    }
    /**
     * Instance of the paginator component used by the table to control what page of the data is
     * displayed. Page changes emitted by the paginator will trigger an update to the
     * table's rendered data.
     *
     * Note that the data source uses the paginator's properties to calculate which page of data
     * should be displayed. If the paginator receives its properties as template inputs,
     * e.g. `[pageLength]=100` or `[pageIndex]=1`, then be sure that the paginator's view has been
     * initialized before assigning it to this data source.
     */
    get paginator() {
        return this._paginator;
    }
    set paginator(paginator) {
        this._paginator = paginator;
        this._updateChangeSubscription();
    }
    constructor(initialData = []) {
        super();
        /** Stream emitting render data to the table (depends on ordered data changes). */
        this._renderData = new BehaviorSubject([]);
        /** Stream that emits when a new filter string is set on the data source. */
        this._filter = new BehaviorSubject('');
        /** Used to react to internal changes of the paginator that are made by the data source itself. */
        this._internalPageChanges = new Subject();
        /**
         * Subscription to the changes that should trigger an update to the table's rendered rows, such
         * as filtering, sorting, pagination, or base data changes.
         */
        this._renderChangesSubscription = null;
        /**
         * Data accessor function that is used for accessing data properties for sorting through
         * the default sortData function.
         * This default function assumes that the sort header IDs (which defaults to the column name)
         * matches the data's properties (e.g. column Xyz represents data['Xyz']).
         * May be set to a custom function for different behavior.
         * @param data Data object that is being accessed.
         * @param sortHeaderId The name of the column that represents the data.
         */
        this.sortingDataAccessor = (data, sortHeaderId) => {
            // eslint-disable-next-line @typescript-eslint/no-explicit-any
            const value = data[sortHeaderId];
            if (_isNumberValue(value)) {
                const numberValue = Number(value);
                // Numbers beyond `MAX_SAFE_INTEGER` can't be compared reliably so we
                // leave them as strings. For more info: https://goo.gl/y5vbSg
                return numberValue < MAX_SAFE_INTEGER ? numberValue : value;
            }
            return value;
        };
        /**
         * Gets a sorted copy of the data array based on the state of the NgbSort. Called
         * after changes are made to the filtered data or when sort changes are emitted from NgbSort.
         * By default, the function retrieves the active sort and its direction and compares data
         * by retrieving data using the sortingDataAccessor. May be overridden for a custom implementation
         * of data ordering.
         * @param data The array of data that should be sorted.
         * @param sort The connected NgbSort that holds the current sort state.
         */
        this.sortData = (data, sort) => {
            const active = sort.active;
            const direction = sort.direction;
            if (!active || direction == '') {
                return data;
            }
            return data.sort((a, b) => {
                let valueA = this.sortingDataAccessor(a, active);
                let valueB = this.sortingDataAccessor(b, active);
                // If there are data in the column that can be converted to a number,
                // it must be ensured that the rest of the data
                // is of the same type so as not to order incorrectly.
                const valueAType = typeof valueA;
                const valueBType = typeof valueB;
                if (valueAType !== valueBType) {
                    if (valueAType === 'number') {
                        valueA += '';
                    }
                    if (valueBType === 'number') {
                        valueB += '';
                    }
                }
                // If both valueA and valueB exist (truthy), then compare the two. Otherwise, check if
                // one value exists while the other doesn't. In this case, existing value should come last.
                // This avoids inconsistent results when comparing values to undefined/null.
                // If neither value exists, return 0 (equal).
                let comparatorResult = 0;
                if (valueA != null && valueB != null) {
                    // Check if one value is greater than the other; if equal, comparatorResult should remain 0.
                    if (valueA > valueB) {
                        comparatorResult = 1;
                    }
                    else if (valueA < valueB) {
                        comparatorResult = -1;
                    }
                }
                else if (valueA != null) {
                    comparatorResult = 1;
                }
                else if (valueB != null) {
                    comparatorResult = -1;
                }
                return comparatorResult * (direction == 'asc' ? 1 : -1);
            });
        };
        /**
         * Checks if a data object matches the data source's filter string. By default, each data object
         * is converted to a string of its properties and returns true if the filter has
         * at least one occurrence in that string. By default, the filter string has its whitespace
         * trimmed and the match is case-insensitive. May be overridden for a custom implementation of
         * filter matching.
         * @param data Data object used to check against the filter.
         * @param filter Filter string that has been set on the data source.
         * @returns Whether the filter matches against the data
         */
        this.filterPredicate = (data, filter) => {
            // Transform the data into a lowercase string of all property values.
            // eslint-disable-next-line @typescript-eslint/no-explicit-any
            const dataStr = Object.keys(data)
                .reduce((currentTerm, key) => {
                // Use an obscure Unicode character to delimit the words in the concatenated string.
                // This avoids matches where the values of two columns combined will match the user's query
                // (e.g. `Flute` and `Stop` will match `Test`). The character is intended to be something
                // that has a very low chance of being typed in by somebody in a text field. This one in
                // particular is "White up-pointing triangle with dot" from
                // https://en.wikipedia.org/wiki/List_of_Unicode_characters
                // eslint-disable-next-line @typescript-eslint/no-explicit-any
                return currentTerm + data[key] + '◬';
            }, '')
                .toLowerCase();
            // Transform the filter by converting it to lowercase and removing whitespace.
            const transformedFilter = filter.trim().toLowerCase();
            return dataStr.indexOf(transformedFilter) != -1;
        };
        this._data = new BehaviorSubject(initialData);
        this._updateChangeSubscription();
    }
    /**
     * Subscribe to changes that should trigger an update to the table's rendered rows. When the
     * changes occur, process the current state of the filter, sort, and pagination along with
     * the provided base data and send it to the table for rendering.
     */
    _updateChangeSubscription() {
        // Sorting and/or pagination should be watched if sort and/or paginator are provided.
        // The events should emit whenever the component emits a change or initializes, or if no
        // component is provided, a stream with just a null event should be provided.
        // The `sortChange` and `pageChange` acts as a signal to the combineLatests below so that the
        // pipeline can progress to the next step. Note that the value from these streams are not used,
        // they purely act as a signal to progress in the pipeline.
        const sortChange = this._sort
            ? merge(this._sort.sortChange, this._sort.initialized)
            : of(null);
        const pageChange = this._paginator
            ? merge(of(true), this._paginator.page, this._internalPageChanges, this._paginator.initialized)
            : of(null);
        const dataStream = this._data;
        // Watch for base data or filter changes to provide a filtered set of data.
        const filteredData = combineLatest([dataStream, this._filter]).pipe(map(([data]) => this._filterData(data)));
        // Watch for filtered data or sort changes to provide an ordered set of data.
        const orderedData = combineLatest([filteredData, sortChange]).pipe(map(([data]) => this._orderData(data)));
        // Watch for ordered data or page changes to provide a paged set of data.
        const paginatedData = combineLatest([orderedData, pageChange]).pipe(map(([data]) => this._pageData(data)));
        // Watched for paged data changes and send the result to the table to render.
        this._renderChangesSubscription?.unsubscribe();
        this._renderChangesSubscription = paginatedData.subscribe((data) => this._renderData.next(data));
    }
    /**
     * Returns a filtered data array where each filter object contains the filter string within
     * the result of the filterPredicate function. If no filter is set, returns the data array
     * as provided.
     */
    _filterData(data) {
        // If there is a filter string, filter out data that does not contain it.
        // Each data object is converted to a string using the function defined by filterPredicate.
        // May be overridden for customization.
        this.filteredData = this.filter == null || this.filter === '' ? data : data.filter((obj) => this.filterPredicate(obj, this.filter));
        if (this.paginator) {
            this._updatePaginator(this.filteredData.length);
        }
        return this.filteredData;
    }
    /**
     * Returns a sorted copy of the data if NgbSort has a sort applied, otherwise just returns the
     * data array as provided. Uses the default data accessor for data lookup, unless a
     * sortDataAccessor function is defined.
     */
    _orderData(data) {
        // If there is no active sort or direction, return the data without trying to sort.
        if (!this.sort) {
            return data;
        }
        return this.sortData(data.slice(), this.sort);
    }
    /**
     * Returns a paged slice of the provided data array according to the provided paginator's page
     * index and length. If there is no paginator provided, returns the data array as provided.
     */
    _pageData(data) {
        if (!this.paginator) {
            return data;
        }
        const startIndex = this.paginator.pageIndex * this.paginator.pageSize;
        return data.slice(startIndex, startIndex + this.paginator.pageSize);
    }
    /**
     * Updates the paginator to reflect the length of the filtered data, and makes sure that the page
     * index does not exceed the paginator's last page. Values are changed in a resolved promise to
     * guard against making property changes within a round of change detection.
     */
    _updatePaginator(filteredDataLength) {
        Promise.resolve().then(() => {
            const paginator = this.paginator;
            if (!paginator) {
                return;
            }
            paginator.length = filteredDataLength;
            // If the page index is set beyond the page, reduce it to the last page.
            if (paginator.pageIndex > 0) {
                const lastPageIndex = Math.ceil(paginator.length / paginator.pageSize) - 1 || 0;
                const newPageIndex = Math.min(paginator.pageIndex, lastPageIndex);
                if (newPageIndex !== paginator.pageIndex) {
                    paginator.pageIndex = newPageIndex;
                    // Since the paginator only emits after user-generated changes,
                    // we need our own stream so we know to should re-render the data.
                    this._internalPageChanges.next();
                }
            }
        });
    }
    /**
     * Used by the NgbTable. Called when it connects to the data source.
     * @docs-private
     */
    connect() {
        if (!this._renderChangesSubscription) {
            this._updateChangeSubscription();
        }
        return this._renderData;
    }
    /**
     * Used by the NgbTable. Called when it disconnects from the data source.
     * @docs-private
     */
    disconnect() {
        this._renderChangesSubscription?.unsubscribe();
        this._renderChangesSubscription = null;
    }
}

/**
 * @license
 * Original work Copyright Google LLC All Rights Reserved.
 * Modified work Copyright DatePoll-Systems
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */
// We can't reuse `CDK_ROW_TEMPLATE` because it's incompatible with local compilation mode.
const ROW_TEMPLATE = `<ng-container cdkCellOutlet></ng-container>`;
/**
 * Header row definition for the ngb-table.
 * Captures the header row's template and other header properties such as the columns to display.
 */
class NgbHeaderRowDef extends CdkHeaderRowDef {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.0.3", ngImport: i0, type: NgbHeaderRowDef, deps: null, target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "16.1.0", version: "19.0.3", type: NgbHeaderRowDef, isStandalone: true, selector: "[ngbHeaderRowDef]", inputs: { columns: ["ngbHeaderRowDef", "columns"], sticky: ["ngbHeaderRowDefSticky", "sticky", booleanAttribute] }, providers: [{ provide: CdkHeaderRowDef, useExisting: NgbHeaderRowDef }], usesInheritance: true, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.0.3", ngImport: i0, type: NgbHeaderRowDef, decorators: [{
            type: Directive,
            args: [{
                    selector: '[ngbHeaderRowDef]',
                    providers: [{ provide: CdkHeaderRowDef, useExisting: NgbHeaderRowDef }],
                    inputs: [
                        { name: 'columns', alias: 'ngbHeaderRowDef' },
                        { name: 'sticky', alias: 'ngbHeaderRowDefSticky', transform: booleanAttribute },
                    ],
                    standalone: true,
                }]
        }] });
/**
 * Footer row definition for the ngb-table.
 * Captures the footer row's template and other footer properties such as the columns to display.
 */
class NgbFooterRowDef extends CdkFooterRowDef {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.0.3", ngImport: i0, type: NgbFooterRowDef, deps: null, target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "16.1.0", version: "19.0.3", type: NgbFooterRowDef, isStandalone: true, selector: "[ngbFooterRowDef]", inputs: { columns: ["ngbFooterRowDef", "columns"], sticky: ["ngbFooterRowDefSticky", "sticky", booleanAttribute] }, providers: [{ provide: CdkFooterRowDef, useExisting: NgbFooterRowDef }], usesInheritance: true, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.0.3", ngImport: i0, type: NgbFooterRowDef, decorators: [{
            type: Directive,
            args: [{
                    selector: '[ngbFooterRowDef]',
                    providers: [{ provide: CdkFooterRowDef, useExisting: NgbFooterRowDef }],
                    inputs: [
                        { name: 'columns', alias: 'ngbFooterRowDef' },
                        { name: 'sticky', alias: 'ngbFooterRowDefSticky', transform: booleanAttribute },
                    ],
                    standalone: true,
                }]
        }] });
/**
 * Data row definition for the ngb-table.
 * Captures the data row's template and other properties such as the columns to display and
 * a when predicate that describes when this row should be used.
 */
class NgbRowDef extends CdkRowDef {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.0.3", ngImport: i0, type: NgbRowDef, deps: null, target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "19.0.3", type: NgbRowDef, isStandalone: true, selector: "[ngbRowDef]", inputs: { columns: ["ngbRowDefColumns", "columns"], when: ["ngbRowDefWhen", "when"] }, providers: [{ provide: CdkRowDef, useExisting: NgbRowDef }], usesInheritance: true, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.0.3", ngImport: i0, type: NgbRowDef, decorators: [{
            type: Directive,
            args: [{
                    selector: '[ngbRowDef]',
                    providers: [{ provide: CdkRowDef, useExisting: NgbRowDef }],
                    inputs: [
                        { name: 'columns', alias: 'ngbRowDefColumns' },
                        { name: 'when', alias: 'ngbRowDefWhen' },
                    ],
                    standalone: true,
                }]
        }] });
/** Header template container that contains the cell outlet. Adds the right class and role. */
class NgbHeaderRow extends CdkHeaderRow {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.0.3", ngImport: i0, type: NgbHeaderRow, deps: null, target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "19.0.3", type: NgbHeaderRow, isStandalone: true, selector: "ngb-header-row, tr[ngb-header-row]", host: { attributes: { "role": "row" } }, providers: [{ provide: CdkHeaderRow, useExisting: NgbHeaderRow }], exportAs: ["ngbHeaderRow"], usesInheritance: true, ngImport: i0, template: "<ng-container cdkCellOutlet></ng-container>", isInline: true, dependencies: [{ kind: "directive", type: CdkCellOutlet, selector: "[cdkCellOutlet]" }], changeDetection: i0.ChangeDetectionStrategy.Default, encapsulation: i0.ViewEncapsulation.None }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.0.3", ngImport: i0, type: NgbHeaderRow, decorators: [{
            type: Component,
            args: [{
                    selector: 'ngb-header-row, tr[ngb-header-row]',
                    template: ROW_TEMPLATE,
                    host: {
                        role: 'row',
                    },
                    // See note on CdkTable for explanation on why this uses the default change detection strategy.
                    // tslint:disable-next-line:validate-decorators
                    changeDetection: ChangeDetectionStrategy.Default,
                    encapsulation: ViewEncapsulation.None,
                    exportAs: 'ngbHeaderRow',
                    providers: [{ provide: CdkHeaderRow, useExisting: NgbHeaderRow }],
                    imports: [CdkCellOutlet],
                }]
        }] });
/** Footer template container that contains the cell outlet. Adds the right class and role. */
class NgbFooterRow extends CdkFooterRow {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.0.3", ngImport: i0, type: NgbFooterRow, deps: null, target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "19.0.3", type: NgbFooterRow, isStandalone: true, selector: "ngb-footer-row, tr[ngb-footer-row]", host: { attributes: { "role": "row" } }, providers: [{ provide: CdkFooterRow, useExisting: NgbFooterRow }], exportAs: ["ngbFooterRow"], usesInheritance: true, ngImport: i0, template: "<ng-container cdkCellOutlet></ng-container>", isInline: true, dependencies: [{ kind: "directive", type: CdkCellOutlet, selector: "[cdkCellOutlet]" }], changeDetection: i0.ChangeDetectionStrategy.Default, encapsulation: i0.ViewEncapsulation.None }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.0.3", ngImport: i0, type: NgbFooterRow, decorators: [{
            type: Component,
            args: [{
                    selector: 'ngb-footer-row, tr[ngb-footer-row]',
                    template: ROW_TEMPLATE,
                    host: {
                        role: 'row',
                    },
                    // See note on CdkTable for explanation on why this uses the default change detection strategy.
                    // tslint:disable-next-line:validate-decorators
                    changeDetection: ChangeDetectionStrategy.Default,
                    encapsulation: ViewEncapsulation.None,
                    exportAs: 'ngbFooterRow',
                    providers: [{ provide: CdkFooterRow, useExisting: NgbFooterRow }],
                    imports: [CdkCellOutlet],
                }]
        }] });
/** Data row template container that contains the cell outlet. Adds the right class and role. */
class NgbRow extends CdkRow {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.0.3", ngImport: i0, type: NgbRow, deps: null, target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "19.0.3", type: NgbRow, isStandalone: true, selector: "ngb-row, tr[ngb-row]", host: { attributes: { "role": "row" } }, providers: [{ provide: CdkRow, useExisting: NgbRow }], exportAs: ["ngbRow"], usesInheritance: true, ngImport: i0, template: "<ng-container cdkCellOutlet></ng-container>", isInline: true, dependencies: [{ kind: "directive", type: CdkCellOutlet, selector: "[cdkCellOutlet]" }], changeDetection: i0.ChangeDetectionStrategy.Default, encapsulation: i0.ViewEncapsulation.None }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.0.3", ngImport: i0, type: NgbRow, decorators: [{
            type: Component,
            args: [{
                    selector: 'ngb-row, tr[ngb-row]',
                    template: ROW_TEMPLATE,
                    host: {
                        role: 'row',
                    },
                    // See note on CdkTable for explanation on why this uses the default change detection strategy.
                    // tslint:disable-next-line:validate-decorators
                    changeDetection: ChangeDetectionStrategy.Default,
                    encapsulation: ViewEncapsulation.None,
                    exportAs: 'ngbRow',
                    providers: [{ provide: CdkRow, useExisting: NgbRow }],
                    imports: [CdkCellOutlet],
                }]
        }] });
/** Row that can be used to display a message when no data is shown in the table. */
class NgbNoDataRow extends CdkNoDataRow {
    constructor() {
        super(...arguments);
        this._contentClassName = 'ngb-no-data-row';
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.0.3", ngImport: i0, type: NgbNoDataRow, deps: null, target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "19.0.3", type: NgbNoDataRow, isStandalone: true, selector: "ng-template[ngbNoDataRow]", providers: [{ provide: CdkNoDataRow, useExisting: NgbNoDataRow }], usesInheritance: true, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.0.3", ngImport: i0, type: NgbNoDataRow, decorators: [{
            type: Directive,
            args: [{
                    selector: 'ng-template[ngbNoDataRow]',
                    providers: [{ provide: CdkNoDataRow, useExisting: NgbNoDataRow }],
                    standalone: true,
                }]
        }] });

/**
 * @license
 * Original work Copyright Google LLC All Rights Reserved.
 * Modified work Copyright DatePoll-Systems
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */
/**
 * Enables the recycle view repeater strategy, which reduces rendering latency. Not compatible with
 * tables that animate rows.
 */
class NgbRecycleRows {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.0.3", ngImport: i0, type: NgbRecycleRows, deps: [], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "19.0.3", type: NgbRecycleRows, isStandalone: true, selector: "ngb-table[recycleRows], table[ngb-table][recycleRows]", providers: [{ provide: _VIEW_REPEATER_STRATEGY, useClass: _RecycleViewRepeaterStrategy }], ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.0.3", ngImport: i0, type: NgbRecycleRows, decorators: [{
            type: Directive,
            args: [{
                    selector: 'ngb-table[recycleRows], table[ngb-table][recycleRows]',
                    providers: [{ provide: _VIEW_REPEATER_STRATEGY, useClass: _RecycleViewRepeaterStrategy }],
                }]
        }] });
/**
 * Wrapper for the CdkTable with Bootstrap styles.
 */
class NgbTable extends CdkTable {
    constructor() {
        super(...arguments);
        /** Overrides the need to add position: sticky on every sticky cell element in `CdkTable`. */
        this.needsPositionStickyOnElement = false;
        this.cdkTable = true;
        this.table = true;
        this.hover = false;
        this.striped = false;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.0.3", ngImport: i0, type: NgbTable, deps: null, target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "19.0.3", type: NgbTable, isStandalone: true, selector: "ngb-table, table[ngb-table]", inputs: { hover: ["hover", "hover", booleanAttribute], striped: ["striped", "striped", booleanAttribute] }, host: { properties: { "class.cdk-table": "this.cdkTable", "class.table": "this.table", "class.table-hover": "this.hover", "class.table-striped": "this.striped" } }, providers: [
            { provide: CdkTable, useExisting: NgbTable },
            { provide: CDK_TABLE, useExisting: NgbTable },
            { provide: _COALESCED_STYLE_SCHEDULER, useClass: _CoalescedStyleScheduler },
            { provide: _VIEW_REPEATER_STRATEGY, useClass: _DisposeViewRepeaterStrategy },
            // Prevent nested tables from seeing this table's StickyPositioningListener.
            { provide: STICKY_POSITIONING_LISTENER, useValue: null },
        ], exportAs: ["ngbTable"], usesInheritance: true, ngImport: i0, template: `
    <ng-content select="caption" />
    <ng-content select="colgroup, col" />

    <!--
      Unprojected content throws a hydration error so we need this to capture it.
      It gets removed on the client so it doesn't affect the layout.
    -->
    @if (_isServer) {
      <ng-content />
    }

    @if (_isNativeHtmlTable) {
      <thead role="rowgroup">
        <ng-container headerRowOutlet />
      </thead>
      <tbody class="mdc-data-table__content" role="rowgroup">
        <ng-container rowOutlet />
        <ng-container noDataRowOutlet />
      </tbody>
      <tfoot role="rowgroup">
        <ng-container footerRowOutlet />
      </tfoot>
    } @else {
      <ng-container headerRowOutlet />
      <ng-container rowOutlet />
      <ng-container noDataRowOutlet />
      <ng-container footerRowOutlet />
    }
  `, isInline: true, dependencies: [{ kind: "directive", type: HeaderRowOutlet, selector: "[headerRowOutlet]" }, { kind: "directive", type: DataRowOutlet, selector: "[rowOutlet]" }, { kind: "directive", type: NoDataRowOutlet, selector: "[noDataRowOutlet]" }, { kind: "directive", type: FooterRowOutlet, selector: "[footerRowOutlet]" }], changeDetection: i0.ChangeDetectionStrategy.Default, encapsulation: i0.ViewEncapsulation.None }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.0.3", ngImport: i0, type: NgbTable, decorators: [{
            type: Component,
            args: [{
                    selector: 'ngb-table, table[ngb-table]',
                    exportAs: 'ngbTable',
                    // Note that according to MDN, the `caption` element has to be projected as the **first**
                    // element in the table. See https://developer.mozilla.org/en-US/docs/Web/HTML/Element/caption
                    // We can't reuse `CDK_TABLE_TEMPLATE` because it's incompatible with local compilation mode.
                    template: `
    <ng-content select="caption" />
    <ng-content select="colgroup, col" />

    <!--
      Unprojected content throws a hydration error so we need this to capture it.
      It gets removed on the client so it doesn't affect the layout.
    -->
    @if (_isServer) {
      <ng-content />
    }

    @if (_isNativeHtmlTable) {
      <thead role="rowgroup">
        <ng-container headerRowOutlet />
      </thead>
      <tbody class="mdc-data-table__content" role="rowgroup">
        <ng-container rowOutlet />
        <ng-container noDataRowOutlet />
      </tbody>
      <tfoot role="rowgroup">
        <ng-container footerRowOutlet />
      </tfoot>
    } @else {
      <ng-container headerRowOutlet />
      <ng-container rowOutlet />
      <ng-container noDataRowOutlet />
      <ng-container footerRowOutlet />
    }
  `,
                    providers: [
                        { provide: CdkTable, useExisting: NgbTable },
                        { provide: CDK_TABLE, useExisting: NgbTable },
                        { provide: _COALESCED_STYLE_SCHEDULER, useClass: _CoalescedStyleScheduler },
                        { provide: _VIEW_REPEATER_STRATEGY, useClass: _DisposeViewRepeaterStrategy },
                        // Prevent nested tables from seeing this table's StickyPositioningListener.
                        { provide: STICKY_POSITIONING_LISTENER, useValue: null },
                    ],
                    encapsulation: ViewEncapsulation.None,
                    // See note on CdkTable for explanation on why this uses the default change detection strategy.
                    // tslint:disable-next-line:validate-decorators
                    changeDetection: ChangeDetectionStrategy.Default,
                    imports: [HeaderRowOutlet, DataRowOutlet, NoDataRowOutlet, FooterRowOutlet],
                }]
        }], propDecorators: { cdkTable: [{
                type: HostBinding,
                args: ['class.cdk-table']
            }], table: [{
                type: HostBinding,
                args: ['class.table']
            }], hover: [{
                type: HostBinding,
                args: ['class.table-hover']
            }, {
                type: Input,
                args: [{ transform: booleanAttribute }]
            }], striped: [{
                type: HostBinding,
                args: ['class.table-striped']
            }, {
                type: Input,
                args: [{ transform: booleanAttribute }]
            }] } });

/**
 * @license
 * Original work Copyright Google LLC All Rights Reserved.
 * Modified work Copyright DatePoll-Systems
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */
/**
 * Column that simply shows text content for the header and row cells. Assumes that the table
 * is using the native table implementation (`<table>`).
 *
 * By default, the name of this column will be the header text and data property accessor.
 * The header text can be overridden with the `headerText` input. Cell values can be overridden with
 * the `dataAccessor` input. Change the text justification to the start or end using the `justify`
 * input.
 */
class NgbTextColumn extends CdkTextColumn {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.0.3", ngImport: i0, type: NgbTextColumn, deps: null, target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "19.0.3", type: NgbTextColumn, isStandalone: true, selector: "ngb-text-column", usesInheritance: true, ngImport: i0, template: `
    <ng-container ngbColumnDef>
      <th ngb-header-cell *ngbHeaderCellDef [style.text-align]="justify">
        {{ headerText }}
      </th>
      <td ngb-cell *ngbCellDef="let data" [style.text-align]="justify">
        {{ dataAccessor(data, name) }}
      </td>
    </ng-container>
  `, isInline: true, dependencies: [{ kind: "directive", type: NgbColumnDef, selector: "[ngbColumnDef]", inputs: ["ngbColumnDef"] }, { kind: "directive", type: NgbHeaderCellDef, selector: "[ngbHeaderCellDef]", inputs: ["whiteSpace"] }, { kind: "directive", type: NgbHeaderCell, selector: "ngb-header-cell, th[ngb-header-cell]" }, { kind: "directive", type: NgbCellDef, selector: "[ngbCellDef]", inputs: ["ngbCellDefTable"] }, { kind: "directive", type: NgbCell, selector: "ngb-cell, td[ngb-cell]", inputs: ["whiteSpace"] }], changeDetection: i0.ChangeDetectionStrategy.Default, encapsulation: i0.ViewEncapsulation.None }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.0.3", ngImport: i0, type: NgbTextColumn, decorators: [{
            type: Component,
            args: [{
                    selector: 'ngb-text-column',
                    template: `
    <ng-container ngbColumnDef>
      <th ngb-header-cell *ngbHeaderCellDef [style.text-align]="justify">
        {{ headerText }}
      </th>
      <td ngb-cell *ngbCellDef="let data" [style.text-align]="justify">
        {{ dataAccessor(data, name) }}
      </td>
    </ng-container>
  `,
                    encapsulation: ViewEncapsulation.None,
                    // Change detection is intentionally not set to OnPush. This component's template will be provided
                    // to the table to be inserted into its view. This is problematic when change detection runs since
                    // the bindings in this template will be evaluated _after_ the table's view is evaluated, which
                    // mean's the template in the table's view will not have the updated value (and in fact will cause
                    // an ExpressionChangedAfterItHasBeenCheckedError).
                    // tslint:disable-next-line:validate-decorators
                    changeDetection: ChangeDetectionStrategy.Default,
                    imports: [NgbColumnDef, NgbHeaderCellDef, NgbHeaderCell, NgbCellDef, NgbCell],
                }]
        }] });

/**
 * @license
 * Original work Copyright Google LLC All Rights Reserved.
 * Modified work Copyright DatePoll-Systems
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */
const EXPORTED_DECLARATIONS = [
    // Table
    NgbTable,
    NgbRecycleRows,
    // Template defs
    NgbHeaderCellDef,
    NgbHeaderRowDef,
    NgbColumnDef,
    NgbCellDef,
    NgbRowDef,
    NgbFooterCellDef,
    NgbFooterRowDef,
    // Cell directives
    NgbHeaderCell,
    NgbCell,
    NgbFooterCell,
    // Row directives
    NgbHeaderRow,
    NgbRow,
    NgbFooterRow,
    NgbNoDataRow,
    NgbTextColumn,
];
class DfxTableModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.0.3", ngImport: i0, type: DfxTableModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "19.0.3", ngImport: i0, type: DfxTableModule, imports: [CdkTableModule, 
            // Table
            NgbTable,
            NgbRecycleRows,
            // Template defs
            NgbHeaderCellDef,
            NgbHeaderRowDef,
            NgbColumnDef,
            NgbCellDef,
            NgbRowDef,
            NgbFooterCellDef,
            NgbFooterRowDef,
            // Cell directives
            NgbHeaderCell,
            NgbCell,
            NgbFooterCell,
            // Row directives
            NgbHeaderRow,
            NgbRow,
            NgbFooterRow,
            NgbNoDataRow,
            NgbTextColumn], exports: [
            // Table
            NgbTable,
            NgbRecycleRows,
            // Template defs
            NgbHeaderCellDef,
            NgbHeaderRowDef,
            NgbColumnDef,
            NgbCellDef,
            NgbRowDef,
            NgbFooterCellDef,
            NgbFooterRowDef,
            // Cell directives
            NgbHeaderCell,
            NgbCell,
            NgbFooterCell,
            // Row directives
            NgbHeaderRow,
            NgbRow,
            NgbFooterRow,
            NgbNoDataRow,
            NgbTextColumn] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "19.0.3", ngImport: i0, type: DfxTableModule, imports: [CdkTableModule] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.0.3", ngImport: i0, type: DfxTableModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [CdkTableModule, ...EXPORTED_DECLARATIONS],
                    exports: [EXPORTED_DECLARATIONS],
                }]
        }] });

/*
 * Public API Surface of dfx-bootstrap-table
 */

/**
 * Generated bundle index. Do not edit.
 */

export { DfxPaginationModule, DfxSortModule, DfxTableModule, NGB_PAGINATOR_DEFAULT_OPTIONS, NGB_PAGINATOR_INTL_PROVIDER, NGB_PAGINATOR_INTL_PROVIDER_FACTORY, NGB_SORT_DEFAULT_OPTIONS, NgbCell, NgbCellDef, NgbColumnDef, NgbFooterCell, NgbFooterCellDef, NgbFooterRow, NgbFooterRowDef, NgbHeaderCell, NgbHeaderCellDef, NgbHeaderRow, NgbHeaderRowDef, NgbNoDataRow, NgbPaginator, NgbPaginatorIntl, NgbRecycleRows, NgbRow, NgbRowDef, NgbSort, NgbSortHeader, NgbTable, NgbTableDataSource, NgbTextColumn };
//# sourceMappingURL=dfx-bootstrap-table.mjs.map
